<template>
  <div class="mod-config">
    <basic-container>
      <ttable
        :table="table"
        @handleSelectionChange="handleSelectionChange"
        @rowClick = "rowClick"
        :uploadInfo="uploadInfo"
        :prelang="prelang"
        :options="options"
        :bottomOffset="100"
        :ajaxFun="ajaxFun"
        ref="checkTable"
      >
        <template #toolbar></template>
      </ttable>
      <!-- 弹窗, 新增 / 修改 -->
      <check-detail :currshowlist.sync="showCheckDetail" ref="CheckDetail" :paramObj="paramObj" @refreshDataList="getData"></check-detail>
      <CheckDiffAdjDetail :currshowlist.sync="showCheckDiffAdj" ref="CheckDiffAdj":paramArr="paramArr" @refreshDataList="getData"></CheckDiffAdjDetail>
    </basic-container>
  </div>
</template>

<script>
  import {delObj, getCheckMainPage} from '@/api/warehouse/checkmain'
  import CheckDetail from './checkdetail'
  import {mapGetters} from 'vuex'
  import ttable from '@/views/common/ztt-table.vue';
  import {checkMainPerform, checkMainSubmit} from "../../../api/warehouse/checkmain";
  import CheckDiffAdjDetail from './checkdiffadjdetail'

  export default {
    data () {
      return {
        ajaxFun:getCheckMainPage,
        paramObj:{},
        paramArr:[],
        showCheckDiffAdj:false,
        showCheckDetail:false,
        factoryOption:[],
        warehouseOptions:[],
        multipleSelection: [],
        isShowQuery:false,
        uploadInfo:{//是否展示上传EXCEL以及对应的url
          isShow:false,
          url:''
        },
        prelang:"operation",
        options: {
          height:300,//默认高度-为了表头固定
          stripe: true, // 是否为斑马纹 table
          highlightCurrentRow: false, // 是否要高亮当前行
          border:true,//是否有纵向边框
          lazy:false,//是否需要懒加载
          fit:true,//列的宽度是否自撑开
          multiSelect:false,//
          seqNo:true,
          isRefresh:true,//是否显示刷新按钮
          isShowHide:true,//是否显示显影按钮
          isSearch:false,//高级查询按钮
          defaultOrderBy:{column:'createTime',direction:'desc'}
        },
        table: {
          total: 0,
          currentPage: 1,
          pageSize: 20,
          data:[],
          // 标题
          column: [
            //盘点编号
            {minWidth:'140',prop:"chkNo",label:"盘点编号",sort: true,isTrue:true,isSearch:true,searchInfoType:'text'},
            //工厂
            {minWidth:'120',prop: "factoryName",label:"工厂",sort: true,isTrue:true,isSearch:true, searchInfoType:'text'},
            //仓库
            {minWidth:'200',prop: "warehouseName",label:"仓库",sort: true,isTrue:true,isSearch:true,searchInfoType:'text'},
            //盘点类型
            {minWidth:'140',prop:"chkType",label:"盘点类型",sort: true,isTrue:true,isSearch:false,searchInfoType:'text'},
            //盘点描述
            {minWidth:'120',prop: "chkDesc",label:"盘点描述",sort: true,isTrue:true,isSearch:true,searchInfoType:'text'},
            //零件
            {minWidth:'140',prop:"partId",label:"零件",sort: true,isTrue:true,isSearch:false,searchInfoType:'text'},
            //库位
            {minWidth:'120',prop: "locationId",label:"库位",sort: true,isTrue:true,isSearch:true,searchInfoType:'text'},
            //状态
            {minWidth:'120',prop: "chkStatus",label:"状态",sort: true,isTrue:true,isSearch:true,searchInfoType:'text'},
            //库位
            {minWidth:'120',width:'200px',prop: "createTime",label:"创建时间",sort: true,isTrue:true,isSearch:true,searchInfoType:'datetimerange'},
            //状态
            {minWidth:'120',width:'200px',prop: "updateTime",label:"更新时间",sort: true,isTrue:true,isSearch:true,searchInfoType:'datetimerange'},
          ],
          toolbar: [
            {
              text: '查看调整历史',
              fun: this.checkDiffAdj,
              disabled: this.disabled,
              permitArr: []
            },
            {
              text: '提交',
              fun: this.submitCheck,
              disabled: this.disabled,
              permitArr: ['盘点中']
            }
          ],
          operator:[
            {
              text: '查询',
              type: 'text',
              size: 'small',
              fun: this.addOrUpdateHandle,
            },
            {
              text: '删除',
              type: 'text',
              size: 'small',
              fun: this.deleteHandle,
              show:{
                val:['未下发'],
                key:'chkStatus'
              }
            }
          ],
          operatorConfig:{
            fixed:'right',
            label:'操作',
            width:200,
            minWidth:100
          },
        },
      }
    },
    components: {
      ttable,
      CheckDetail,
      CheckDiffAdjDetail
    },
    computed: {
      ...mapGetters(['permissions'])
    },
    methods: {
      // 获取数据列表
      getData () {
        this.$refs.checkTable.getDataList();
      },
      checkPerformed(){
        if(this.multipleSelection.length===0){
          this.$message.success('请选择盘点单号')
          return
        }
        checkMainPerform(this.multipleSelection.map(item => {
          return item.id
        })).then(response => {
          this.$message.success('下发成功')
          this.getData()
        })
      },
      handleSelectionChange(val){
        this.multipleSelection = val
      },
      submitCheck(){
        if(this.multipleSelection==0){
          this.$message.success('请选择盘点单号')
          return
        }
        checkMainSubmit(this.multipleSelection.id).then(response => {
          this.$message.success('下发成功')
          this.getData()
        })
      },
      //查看调整历史
      checkDiffAdj(){
        if(this.multipleSelection==0){
          this.$message.success('请选择盘点单号')
          return
        }
        this.showCheckDiffAdj = true;
        this.paramArr=[this.multipleSelection.id]
      },
      rowClick(row){
        this.multipleSelection = row
      },
      // 新增 / 修改
      addOrUpdateHandle (row) {
        this.showCheckDetail=true;
        this.paramObj={};
        this.paramObj.warehouseCheckId=row==null?null:row.id;
      },
      // 删除
      deleteHandle (row) {
        this.$confirm('是否确认删除ID为' + row.id, '提示', {
          confirmButtonText: '确定',
          cancelButtonText: '取消',
          type: 'warning'
        }).then(function () {
          return delObj(row.id)
        }).then(data => {
          this.$message.success('删除成功')
          this.getData()
        })
      }
    }
  }
</script>
